@@ -67,7 +67,13 @@ has actionCfg => sub {
 
 =head2 actionCfgMap
 
-TODOC
+Lookup table for action plugins.
+
+NOTE: Unique keys are not checked for popup plugins as they don't have
+      action handlers.
+      This allows multiple popup actions using the same plugin instance.
+      In this case an additional cfg parameter C<testingIdPostfix> must be
+      used to make the QoxdooObjectIds unique used from frontend testing.
 
 =cut
 
@@ -77,7 +83,9 @@ has actionCfgMap => sub {
     for my $row (@{$self->actionCfg}){
         next unless $row->{action} =~ /^(submit|upload|download|autoSubmit|save)/;
         next unless $row->{key};
-        $map{$row->{key}} = $row;
+        my $key = $row->{key};
+        die mkerror(4646, "Duplicate action key $key") if exists $map{$key};
+        $map{$key} = $row;
     }
     return \%map;
 };
